import { IInstitutionsRepository } from '@modules/institutions/repositories/IInstitutionsRepository';
import { AppError } from '@shared/error/AppError';
import 'reflect-metadata';
import { inject, injectable } from 'tsyringe';


interface IRequest {
    name: string,
}

@injectable()
class CreateInstitutionUseCase {
    constructor(
        @inject('InstitutionsRepository')
        private institutionsRepository: IInstitutionsRepository
    ) { }

    async execute({ name }: IRequest) {
        const institutionAlreadyExists = await this.institutionsRepository.findByName(name);
        if (institutionAlreadyExists) {
            throw new AppError('Institution already exists', 404);
        }

        const institution = await this.institutionsRepository.create({
            name
        })

        return institution
    }
}

export { CreateInstitutionUseCase }